Class: Aws::MediaStore::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MediaStore::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mediastore/client.rb,
sig/client.rbs
Overview
An API client for MediaStore. To construct a client, you need to configure a :region and :credentials.
client = Aws::MediaStore::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateContainerResponseSuccess, _DeleteContainerPolicyResponseSuccess, _DeleteContainerResponseSuccess, _DeleteCorsPolicyResponseSuccess, _DeleteLifecyclePolicyResponseSuccess, _DeleteMetricPolicyResponseSuccess, _DescribeContainerResponseSuccess, _GetContainerPolicyResponseSuccess, _GetCorsPolicyResponseSuccess, _GetLifecyclePolicyResponseSuccess, _GetMetricPolicyResponseSuccess, _ListContainersResponseSuccess, _ListTagsForResourceResponseSuccess, _PutContainerPolicyResponseSuccess, _PutCorsPolicyResponseSuccess, _PutLifecyclePolicyResponseSuccess, _PutMetricPolicyResponseSuccess, _StartAccessLoggingResponseSuccess, _StopAccessLoggingResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_container(params = {}) ⇒ Types::CreateContainerOutput
Creates a storage container to hold objects.
-
#delete_container(params = {}) ⇒ Struct
Deletes the specified container.
-
#delete_container_policy(params = {}) ⇒ Struct
Deletes the access policy that is associated with the specified container.
-
#delete_cors_policy(params = {}) ⇒ Struct
Deletes the cross-origin resource sharing (CORS) configuration information that is set for the container.
-
#delete_lifecycle_policy(params = {}) ⇒ Struct
Removes an object lifecycle policy from a container.
-
#delete_metric_policy(params = {}) ⇒ Struct
Deletes the metric policy that is associated with the specified container.
-
#describe_container(params = {}) ⇒ Types::DescribeContainerOutput
Retrieves the properties of the requested container.
-
#get_container_policy(params = {}) ⇒ Types::GetContainerPolicyOutput
Retrieves the access policy for the specified container.
-
#get_cors_policy(params = {}) ⇒ Types::GetCorsPolicyOutput
Returns the cross-origin resource sharing (CORS) configuration information that is set for the container.
-
#get_lifecycle_policy(params = {}) ⇒ Types::GetLifecyclePolicyOutput
Retrieves the object lifecycle policy that is assigned to a container.
-
#get_metric_policy(params = {}) ⇒ Types::GetMetricPolicyOutput
Returns the metric policy for the specified container.
-
#list_containers(params = {}) ⇒ Types::ListContainersOutput
Lists the properties of all containers in AWS Elemental MediaStore.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of the tags assigned to the specified container.
-
#put_container_policy(params = {}) ⇒ Struct
Creates an access policy for the specified container to restrict the users and clients that can access it.
-
#put_cors_policy(params = {}) ⇒ Struct
Sets the cross-origin resource sharing (CORS) configuration on a container so that the container can service cross-origin requests.
-
#put_lifecycle_policy(params = {}) ⇒ Struct
Writes an object lifecycle policy to a container.
-
#put_metric_policy(params = {}) ⇒ Struct
The metric policy that you want to add to the container.
-
#start_access_logging(params = {}) ⇒ Struct
Starts access logging on the specified container.
-
#stop_access_logging(params = {}) ⇒ Struct
Stops access logging on the specified container.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified AWS Elemental MediaStore container.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified container.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-mediastore/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1268 1269 1270 |
# File 'lib/aws-sdk-mediastore/client.rb', line 1268 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1271 1272 1273 |
# File 'lib/aws-sdk-mediastore/client.rb', line 1271 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 |
# File 'lib/aws-sdk-mediastore/client.rb', line 1241 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MediaStore') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mediastore' context[:gem_version] = '1.90.0' Seahorse::Client::Request.new(handlers, context) end |
#create_container(params = {}) ⇒ Types::CreateContainerOutput
Creates a storage container to hold objects. A container is similar to a bucket in the Amazon S3 service.
87 |
# File 'sig/client.rbs', line 87
def create_container: (
|
#delete_container(params = {}) ⇒ Struct
Deletes the specified container. Before you make a DeleteContainer
request, delete any objects in the container or in any folders in the
container. You can delete only empty containers.
102 |
# File 'sig/client.rbs', line 102
def delete_container: (
|
#delete_container_policy(params = {}) ⇒ Struct
Deletes the access policy that is associated with the specified container.
111 |
# File 'sig/client.rbs', line 111
def delete_container_policy: (
|
#delete_cors_policy(params = {}) ⇒ Struct
Deletes the cross-origin resource sharing (CORS) configuration information that is set for the container.
To use this operation, you must have permission to perform the
MediaStore:DeleteCorsPolicy action. The container owner has this
permission by default and can grant this permission to others.
120 |
# File 'sig/client.rbs', line 120
def delete_cors_policy: (
|
#delete_lifecycle_policy(params = {}) ⇒ Struct
Removes an object lifecycle policy from a container. It takes up to 20 minutes for the change to take effect.
129 |
# File 'sig/client.rbs', line 129
def delete_lifecycle_policy: (
|
#delete_metric_policy(params = {}) ⇒ Struct
Deletes the metric policy that is associated with the specified container. If there is no metric policy associated with the container, MediaStore doesn't send metrics to CloudWatch.
138 |
# File 'sig/client.rbs', line 138
def delete_metric_policy: (
|
#describe_container(params = {}) ⇒ Types::DescribeContainerOutput
Retrieves the properties of the requested container. This request is
commonly used to retrieve the endpoint of a container. An endpoint is
a value assigned by the service when a new container is created. A
container's endpoint does not change after it has been assigned. The
DescribeContainer request returns a single Container object based
on ContainerName. To return all Container objects that are
associated with a specified AWS account, use ListContainers.
148 |
# File 'sig/client.rbs', line 148
def describe_container: (
|
#get_container_policy(params = {}) ⇒ Types::GetContainerPolicyOutput
Retrieves the access policy for the specified container. For information about the data that is included in an access policy, see the AWS Identity and Access Management User Guide.
158 |
# File 'sig/client.rbs', line 158
def get_container_policy: (
|
#get_cors_policy(params = {}) ⇒ Types::GetCorsPolicyOutput
Returns the cross-origin resource sharing (CORS) configuration information that is set for the container.
To use this operation, you must have permission to perform the
MediaStore:GetCorsPolicy action. By default, the container owner has
this permission and can grant it to others.
168 |
# File 'sig/client.rbs', line 168
def get_cors_policy: (
|
#get_lifecycle_policy(params = {}) ⇒ Types::GetLifecyclePolicyOutput
Retrieves the object lifecycle policy that is assigned to a container.
178 |
# File 'sig/client.rbs', line 178
def get_lifecycle_policy: (
|
#get_metric_policy(params = {}) ⇒ Types::GetMetricPolicyOutput
Returns the metric policy for the specified container.
188 |
# File 'sig/client.rbs', line 188
def get_metric_policy: (
|
#list_containers(params = {}) ⇒ Types::ListContainersOutput
Lists the properties of all containers in AWS Elemental MediaStore.
You can query to receive all the containers in one response. Or you
can include the MaxResults parameter to receive a limited number of
containers in each response. In this case, the response includes a
token. To get the next set of containers, send the command again, this
time with the NextToken parameter (with the returned token as its
value). The next set of responses appears, with a token if there are
still more containers to receive.
See also DescribeContainer, which gets the properties of one container.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
199 |
# File 'sig/client.rbs', line 199
def list_containers: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of the tags assigned to the specified container.
210 |
# File 'sig/client.rbs', line 210
def list_tags_for_resource: (
|
#put_container_policy(params = {}) ⇒ Struct
Creates an access policy for the specified container to restrict the users and clients that can access it. For information about the data that is included in an access policy, see the AWS Identity and Access Management User Guide.
For this release of the REST API, you can create only one policy for a
container. If you enter PutContainerPolicy twice, the second command
modifies the existing policy.
219 |
# File 'sig/client.rbs', line 219
def put_container_policy: (
|
#put_cors_policy(params = {}) ⇒ Struct
Sets the cross-origin resource sharing (CORS) configuration on a container so that the container can service cross-origin requests. For example, you might want to enable a request whose origin is http://www.example.com to access your AWS Elemental MediaStore container at my.example.container.com by using the browser's XMLHttpRequest capability.
To enable CORS on a container, you attach a CORS policy to the container. In the CORS policy, you configure rules that identify origins and the HTTP methods that can be executed on your container. The policy can contain up to 398,000 characters. You can add up to 100 rules to a CORS policy. If more than one rule applies, the service uses the first applicable rule listed.
To learn more about CORS, see Cross-Origin Resource Sharing (CORS) in AWS Elemental MediaStore.
229 |
# File 'sig/client.rbs', line 229
def put_cors_policy: (
|
#put_lifecycle_policy(params = {}) ⇒ Struct
Writes an object lifecycle policy to a container. If the container already has an object lifecycle policy, the service replaces the existing policy with the new policy. It takes up to 20 minutes for the change to take effect.
For information about how to construct an object lifecycle policy, see Components of an Object Lifecycle Policy.
247 |
# File 'sig/client.rbs', line 247
def put_lifecycle_policy: (
|
#put_metric_policy(params = {}) ⇒ Struct
The metric policy that you want to add to the container. A metric policy allows AWS Elemental MediaStore to send metrics to Amazon CloudWatch. It takes up to 20 minutes for the new policy to take effect.
257 |
# File 'sig/client.rbs', line 257
def put_metric_policy: (
|
#start_access_logging(params = {}) ⇒ Struct
Starts access logging on the specified container. When you enable access logging on a container, MediaStore delivers access logs for objects stored in that container to Amazon CloudWatch Logs.
275 |
# File 'sig/client.rbs', line 275
def start_access_logging: (
|
#stop_access_logging(params = {}) ⇒ Struct
Stops access logging on the specified container. When you stop access logging on a container, MediaStore stops sending access logs to Amazon CloudWatch Logs. These access logs are not saved and are not retrievable.
284 |
# File 'sig/client.rbs', line 284
def stop_access_logging: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified AWS Elemental MediaStore container. Tags are key:value pairs that you can associate with AWS resources. For example, the tag key might be "customer" and the tag value might be "companyA." You can specify one or more tags to add to each container. You can add up to 50 tags to each container. For more information about tagging, including naming and usage conventions, see Tagging Resources in MediaStore.
293 |
# File 'sig/client.rbs', line 293
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified container. You can specify one or more tags to remove.
308 |
# File 'sig/client.rbs', line 308
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1261 1262 1263 |
# File 'lib/aws-sdk-mediastore/client.rb', line 1261 def waiter_names [] end |