Class: Aws::MediaStore::Types::CreateContainerOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaStore::Types::CreateContainerOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediastore/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container ⇒ Types::Container
ContainerARN: The Amazon Resource Name (ARN) of the newly created container.
Instance Attribute Details
#container ⇒ Types::Container
ContainerARN: The Amazon Resource Name (ARN) of the newly created container. The ARN has the following format: arn:aws:<region>:<account that owns this container>:container/<name of container>. For example: arn:aws:mediastore:us-west-2:111122223333:container/movies
ContainerName: The container name as specified in the request.
CreationTime: Unix time stamp.
Status: The status of container creation or deletion. The status is one of the following: CREATING, ACTIVE, or DELETING. While the service is creating the container, the status is CREATING. When an endpoint is available, the status changes to ACTIVE.
The return value does not include the container’s endpoint. To make downstream requests, you must obtain this value by using DescribeContainer or ListContainers.
225 226 227 228 229 |
# File 'lib/aws-sdk-mediastore/types.rb', line 225 class CreateContainerOutput < Struct.new( :container) SENSITIVE = [] include Aws::Structure end |